@@ -4,10 +4,28 @@
 ----
 
 """
+import datetime
+
+模块开始 = datetime.datetime.now()
 
 from Fishconsole import fcv
 from Fishconsole import logs
 from Fishconsole import helps
+import os
+
+
+# 判断设备是否接入网络
+def isConnected():
+    import requests
+    # noinspection PyBroadException
+    try:
+        requests.get("https://pypi.org/project/Fishconsole/", timeout=15)
+    except:
+        print(logs.日志("》强制更新系统》官网连接失败"))
+        return False
+    print(logs.日志("》强制更新系统》官网连接成功"))
+    return True
+
 
 logs.系统日志("用户调用了Fishsys模块")
 # 导入强制更新系统所需要的内容
@@ -545,9 +563,8 @@ def 密码(模式, 原文, 密码: str = ""):
     else:
         c = passwordsys(2, 密码, 原文)
         logs.系统日志(f"c is {c}", PI)
-        d = 字符转unicode(2, c)
-        logs.系统日志(f"d is {d}", PI)
-        return d
+
+        return c
 
 
 # 模式,加密密码,内容
@@ -580,6 +597,7 @@ def 网易云音乐(歌单链接: list):
             for url in urllist:
                 count = count + 1
                 print(logs.颜色(logs.分割线(f"开始第{count}次爬取", "Spider"), 色选="红色"))
+                # noinspection PyBroadException
                 try:
                     result = requests.get(url).text
                 except:
@@ -600,6 +618,7 @@ def 网易云音乐(歌单链接: list):
                                     song_url = f"{base_url}{count_id}.mp3"
                                     logs.系统日志(f'存储文件：{name}.mp3')
                                     music = requests.get(song_url).content
+                                    # noinspection PyBroadException
                                     try:
                                         with open(f'{name}.mp3', "wb") as file:
                                             file.write(music)
@@ -658,13 +677,13 @@ def 缓存(模式, 数据: dict = None, 文件名="Fishconsole.fcc"):
     就是存数据，方便程序在下一次运行的时候调用
 
 
-    :param 模式:1是存储，2是读取
+    模式:1是存储，2是读取
 
-    :param 数据:你要存的数据
+    数据:你要存的数据
 
-    :param 文件名:指定的文件名（默认为Fishconsole.fcc）
+    文件名:指定的文件名（默认为Fishconsole.fcc）
 
-    :return:  文件或者dict类型的值
+    :return:  文件或者dict类型的值，如果没有缓存文件就返回False的布尔值
     """
     模式 = str(模式)
     if 模式 == "1":
@@ -684,7 +703,11 @@ def 缓存(模式, 数据: dict = None, 文件名="Fishconsole.fcc"):
             with open(f'{文件名}', "r") as file:
                 a = file.read()
                 file.close()
-            解密 = passwordsys(2, "", a)
+            # noinspection PyBroadException
+            try:
+                解密 = passwordsys(2, "", a)
+            except:
+                logs.安全退出("缓存》你的缓存文件遭到了非法改动，我们无法从中解析数据")
             解密 = eval(解密)
             解密 = dict(解密)
             logs.系统日志("缓存》读取文件完成", cache)
@@ -696,7 +719,7 @@ def 缓存(模式, 数据: dict = None, 文件名="Fishconsole.fcc"):
             logs.系统日志("缓存》文件存在性检测》指定文件并未发现，将返回布尔类型的False")
             return False
     else:
-        logs.错误跟踪(["Fishconsole", "Fishsys", "缓存"], "请使用合法的模式", 模式)
+        logs.安全退出("缓存》请选择合法的模式")
 
 
 def 字符转unicode(模式, 原文: str):
@@ -747,8 +770,12 @@ def 官网存活性检测(官网地址: str):
     :return: 布尔值
     """
     import requests
+    # noinspection PyBroadException
     try:
-        requests.get(官网地址, timeout=2)
+        headers = {
+            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/101.0.4951.64 Safari/537.36 Edg/101.0.1210.53"
+        }
+        requests.get(官网地址, headers=headers, timeout=15)
     except:
         return False
     return True
@@ -779,15 +806,14 @@ def 讯飞云控(fid):
         header = {
             'User-Agent': 'Mozilla/5.0 (Linux; Android 6.0; Nexus 5 Build/MRA58N) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/101.0.4951.64 Mobile Safari/537.36 Edg/101.0.1210.47'}
         res = requests.get(url, headers=header).text
+        # noinspection PyBroadException
         try:
             res = json.loads(res)["data"]["coop"]["ops"]
             res = res[0]
             res = res["insert"]
             res = res.replace("\n", "")
             res = eval(res)
-            logs.变量查看("res", res)
         except:
-            logs.变量查看("res", res)
             logs.安全退出("Fishsys》讯飞云控》类型转换器》出现意外，可能是解析模式错误或json文档版本过低或者你在云控乱敲")
     else:
         logs.安全退出("Fishsys》讯飞云控》网络链接失败")
@@ -796,37 +822,65 @@ def 讯飞云控(fid):
 
 # 你要删我也没办法，反正如果出了什么错过了重大更新你就自己乐呵去呗
 # 这个不是模块，我们将会在导入该模块的时候顺序执行此处
-# sys是f_debug的强制更新的总开关，如果开启，更新器才会允许运行
+# 你可以去fcv关闭强制更新而不是删代码
+
+# 强制更新系统执行组一期
 sys = fcv.f_debug()
 sys = sys["updata"]
+
 UPI = fcv.f_debug()
 UPI = UPI["updata"]
+# 确认开发者模式是否启动了强制更新
 if sys:
     logs.系统日志("强制更新系统》强制更新系统启动", UPI)
     logs.系统日志("强制更新系统》读取缓存信息", UPI)
+    # 查找缓存文件
     config = 缓存(2)
+    # 如果缓存文件不存在
     if not config:
         logs.系统日志("强制更新系统》缓存》缓存文件不存在，创建缓存文件", UPI)
         # fup的意思是Fishsys模块判断自己是否在之前检测过一次，如果检测过一次，就是修改为正，让它可
         # +以在下一次检测到版本还是低的话继续保持未检测的状态，如果成功了，那就将False修改为ture，这个fupadta是独立的
-        # 而updata是helps.帮助弄过来的，它的用处就是让Fishsys执行强制更新的操作
+        # +而updata是helps.帮助弄过来的，它的用处就是让Fishsys执行强制更新的操作
+
         # 因为没有文件，所以我们在一开始就要创建文件，这个创建文件有一个规则，就是需要创建啥就写入啥，不要一股脑全写，因为这样就显得不高效
-        config = {"updata": True, "fup": False}
+        config = {"updata": True, "fup": False, "year": 2022, "month": 5, "day": 20}
         logs.系统日志("强制更新系统》首次运行，添加fup到缓存", UPI)
-        # 提取数据，其实也是初始化首次启动时要用的变量
+        # 提取数据，其实也是初始化首次启动时要用的变量，因为是第一次启动，所以提取的值就是首次运行的初始值
         fup = config["fup"]
         fupdata = config["updata"]
+        year = config['year']
         # 当变量有点修改的时候我们就要进行保存，因为这样才能避免出现突如其来的故障
         缓存(1, config)
+
     else:
         # 当缓存文件存在时执行的操作
         logs.系统日志(f"缓存文件存在，尝试读取相关信息", UPI)
         logs.系统日志(f"Fishconsole.fcc is {config}", UPI)
         # 因为我们有文件了，我们就可以直接提取数据，但是难免会出现一些奇奇怪怪的情况，所以我们还要检测参数是否存在
+        # 关于fup的信息在822行
         fup = config.get("fup")
         fupdata = config.get("updata")
+        year = config.get("year")
         logs.系统日志(f"fup is {fup}", UPI)
         logs.系统日志(f"fupdata is {fupdata}", UPI)
+        logs.系统日志(f"year is {year}", UPI)
+
+        # 如果get到没有的内容，他就会给你返回False的布尔值
+        if year is None:
+            logs.系统日志("year配置不存在，创建", UPI)
+            config["year"] = 2022
+            config["month"] = 5
+            config["day"] = 20
+            上一年 = config.get("year")
+            上一月 = config.get("month")
+            上一日 = config.get("day")
+            缓存(1, config)
+        else:
+            上一年 = config.get("year")
+            上一月 = config.get("month")
+            上一日 = config.get("day")
+
         if fupdata is None:
             logs.系统日志("fupdata配置不存在，创建", UPI)
             config["updata"] = True
@@ -836,20 +890,69 @@ if sys:
             config["fup"] = True
             fup = config["fup"]
             缓存(1, config)
-    # fupdata在前面的参数提取中就已经搞好了，现在我们只需要执行操作了
+    # 计算经过时间，如果经过的时间大于5，我们就要启动自动更新，通过这种被动更新的方式，我们就能确保用户使用的永远是最新版本
+
+    # 强制更新系统执行组二期
+    import time
+
+    a = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
+    a = a.split(" ")[0]
+    a = a.split("-")
+    年 = int(a[0])
+    月 = int(a[1])
+    日 = int(a[2])
+    上一年 = config.get("year")
+    上一月 = config.get("month")
+    上一日 = config.get("day")
+    if 上一年:
+        # 这是有数据时执行的
+        # noinspection PyStatementEffect
+        1 + 1
+    else:
+        config["year"] = "2005"
+        config["month"] = "6"
+        config["day"] = "3"
+        上一年 = 2005
+        上一月 = 6
+        上一日 = 3
+    # 结束时间就是今天的时间
+    # 开始时间就是自上次记录的时间，首次运行所记录的上次的时间默认为我的生日，不管生活有多么狼狈，生日那天也是要好好奖励自己的
+    结束时间 = datetime.datetime(年, 月, 日)
+    开始时间 = datetime.datetime(上一年, 上一月, 上一日)
+
+    经过时间 = (结束时间 - 开始时间).days
+    if 经过时间 >= 5:
+        config["updata"] = True
+        config["year"] = 年
+        config["month"] = 月
+        config["day"] = 日
+        缓存(1, config)
+        logs.安全退出("强制更新系统》自动更新》Fishconsole Project自动更新已对您设备上的Fishconsole进行了例行的更新检查》请重新启动本程序进行检查")
+
+    # fupdata在前面的参数提取中搞就已经好了，现在我们只需要执行操作了
     if fupdata:
         logs.系统日志("这是updata值为True时执行的操作", UPI)
+        # 查找fup的变量值，关于fup的介绍在822行，他肯定是存在的，如果不存在的就跑不到这一步了
+        # 这是fup开启时执行的操作
         if fup:
-            print(logs.日志(f"》Fishconsole强制更新系统{fcv.version()}》Fishsys 》您的版本过低，请更新至最新版本后重试", "红色"))
-            # 最原始的操作，大家引以为戒
-            # os.remove("Fishconsole.fcc")
-            logs.系统日志(f"fup is {fup}", UPI)
-            # 反转变量值，这样就可以在下一次执行的时候触发更新
-            config["fup"] = False
-            缓存(1, config)
-            logs.安全退出("     <程序正常结束>")
+            # 这是fup开启时执行的操作
+            res = isConnected()
+            if res:
+                # 返回值不是False，就说明官网存活，也说明我们链接上了官网
+                print(logs.日志(f"》Fishconsole强制更新系统{fcv.version()}》Fishsys 》您的版本过低，我们将尝试自动为您更新", "红色"))
+                # 最原始的操作，大家引以为戒
+                # os.remove("Fishconsole.fcc")
+                logs.系统日志(f"fup is {fup}", UPI)
+                # 反转变量值，这样就可以在下一次执行的时候触发更新
+                config["fup"] = False
+                缓存(1, config)
+                os.system("python.exe -m pip install --upgrade pip -i https://pypi.douban.com/simple")
+                os.system(f'pip install Fishconsole --upgrade')
+                logs.安全退出("更新完毕，请重新运行")
+            print(logs.日志("官网链接失败", "红色"))
+
         else:
-            # 这是Fishsys的复检
+            # 这是Fishsys的复检或者是没有fup变量时执行的操作
             print(logs.日志(f"》Fishconsole强制更新系统{fcv.version()}》Fishsys 》正在激活帮助及模块包更新检查工具", "红色"))
             # 反转变量值，这样就可以在下一次时触发警告
             config["fup"] = True
@@ -862,4 +965,8 @@ if sys:
         缓存(1, config)
 else:
     # 这是关闭了更新时执行的操作
-    logs.日志("fcv_debug已取消强制更新系统的执行", "绿色")
+    print(logs.日志(f"Fishconsole{fcv.version()} 开发者您好,我们已经停止了强制更新。请注意，全局配置已重置", "绿色"))
+    print(logs.日志(f"Fishconsole{fcv.version()} 已解锁，您可以使用了", "绿色"))
+模块结束 = datetime.datetime.now()
+
+logs.系统日志(f'Fishsys运行时间为：{模块结束 - 模块开始}')
