@@ -14,13 +14,6 @@ from Fishconsole import window
 from Fishconsole import fcv
 from Fishconsole import Fishsys
 
-
-
-
-
-
-
-
 sys = fcv.f_debug()
 sys = sys["updata"]
 UPI = fcv.f_debug()
@@ -28,14 +21,15 @@ UPI = UPI["UPI"]
 
 
 # 判断设备是否接入网络
+# noinspection PyBroadException
 def isConnected():
     import requests
     try:
-        html = requests.get("https://pypi.org/project/Fishconsole/", timeout=2)
+        requests.get("https://pypi.org/project/Fishconsole/", timeout=15)
     except:
-        logs.系统日志("》强制更新系统》官网连接失败", UPI)
+        print(logs.日志("》强制更新系统》官网连接失败"))
         return False
-    logs.系统日志("》强制更新系统》官网连接成功", UPI)
+    print(logs.日志("》强制更新系统》官网连接成功"))
     return True
 
 
@@ -52,70 +46,64 @@ def 帮助():
     :return: <启动主程序>
     """
 
-
-
+    # 强制更新系统helps端
     sys = fcv.f_debug()
     sys = sys["updata"]
     print(logs.颜色(
         "由于termux存在一些问题，所以easygui无法使用而且matplotlib中文辅助模块要使用jupyter notebook才可以使用，这里就不上相关教程了",
         色选="红色"))
-    if isConnected():
-        print(logs.日志(f"Fishconsole{fcv.version()} 检查更新开始。。。"))
-        v = fcv.version()
-        url = "https://pypi.org/project/Fishconsole/"
-        res = requests.get(url).text
-        res_html = etree.HTML(res)
-        res_v = res_html.xpath("/html/body/main/div[2]/div/div[1]/h1/text()")[0]
-        res_v = str(res_v[21:27])
-        if res_v != v:
+    if sys:
+        if isConnected():
+            print(logs.日志(f"Fishconsole{fcv.version()} 检查更新开始。。。"))
+            v = fcv.version()
+            url = "https://pypi.org/project/Fishconsole/"
+            res = requests.get(url).text
+            res_html = etree.HTML(res)
+            res_v = res_html.xpath("/html/body/main/div[2]/div/div[1]/h1/text()")[0]
+            res_v = str(res_v[21:27])
+            # 检查是否开启了强制更新系统
             if sys:
-                print(logs.日志(f"Fishconsole{fcv.version()} 检查更新结束"))
-                print(logs.日志(f"检测到最新版本号发生了变化({res_v}>{v})，请在终端键入pip install --upgrade Fishconsole更新至最新版本", "红色"))
-                print(logs.日志(f"Fishconsole 模块已被禁用，解决方式为更新该模块", "红色"))
-            else:
-                print(logs.日志(f"f_debug已允许Fishconsole以开发者模式运行", "绿色"))
-            if sys:
-
-                # 尝试获取缓存中的值
-                config = Fishsys.缓存(2)
-                fupdata = config.get("updata")
-                if fupdata:
-                    # 这是Ture时执行的操作
-                    1 + 1
+                # 开启了强制更新系统
+                if res_v == v:
+                    print(logs.日志(f"Fishconsole{fcv.version()} 检查更新结束,您的模块为最新版本", "绿色"))
+                    print(logs.日志(f"Fishconsole{fcv.version()} 已解锁，您可以使用了", "绿色"))
+                    # 尝试获取缓存中的值
+                    config = Fishsys.缓存(2)
+                    if config:
+                        logs.系统日志("变量提取》这是Ture时执行的操作")
+                        config["updata"] = False
+                        Fishsys.缓存(1, config)
+                        config["year"] = 2022
+                        config["month"] = 5
+                        config["day"] = 20
+                    else:
+                        logs.系统日志("变量提取》这是为false是执行的操作")
+                        config = {"year": 2022, "month": 5, "day": 20, "updata": False}
+                        Fishsys.缓存(1, config)
                 else:
-                    # 这是为false是执行的操作
+                    # 对比到版本号不同
+                    print(logs.日志(f"Fishconsole{fcv.version()} 检查更新结束"))
+                    # 尝试获取缓存中的值
+                    config = Fishsys.缓存(2)
+                    # 这是没有检查到值或者发现时执行的操作
+                    print(logs.日志(f"检测到最新版本号发生了变化({res_v}>{v})，请重新运行本程序，我们将尝试自动安装最新版本", "红色"))
+                    print(logs.日志(f"Fishconsole 模块已被禁用，解决方式为更新该模块", "红色"))
                     config["updata"] = True
-                    Fishsys.缓存(1, config)
-                Fishsys.缓存(1, config)
-                logs.安全退出(f"Fishconsole》help》强制更新启动")
-            else:
-                logs.日志(f"Fishconsole》f_debug》已取消强制更新", "绿色")
-                # 尝试获取缓存中的值
-                config = Fishsys.缓存(2)
-                fupdata = config.get("updata")
-                if fupdata:
-                    config["updata"] = False
+                    logs.安全退出(f"Fishconsole》help》强制更新启动")
                     Fishsys.缓存(1, config)
         else:
-            print(logs.日志(f"Fishconsole{fcv.version()} 检查更新结束,您的模块为最新版本", "绿色"))
-            print(logs.日志(f"Fishconsole{fcv.version()} 已解锁，您可以使用了", "绿色"))
-
-            # 尝试获取缓存中的值
-            config = Fishsys.缓存(2)
-            fupdata = config.get("updata")
-            if fupdata:
-                # 这是Ture时执行的操作
-                config["updata"] = False
-                Fishsys.缓存(1, config)
-            else:
-                # 这是为false是执行的操作
-                config["updata"] = False
-                Fishsys.缓存(1, config)
+            print(logs.日志(f"Fishconsole{fcv.version()} 检查更新结束"))
+            print(logs.日志("你的设备无法访问互联网，请检查网络连接"))
     else:
-        print(logs.日志(f"Fishconsole{fcv.version()} 检查更新结束"))
-        print(logs.日志("你的设备无法访问互联网，请检查网络连接"))
+        logs.日志(f"Fishconsole》f_debug》已取消强制更新", "绿色")
+        # 尝试获取缓存中的值
+        config = Fishsys.缓存(2)
+        fupdata = config.get("updata")
+        if fupdata:
+            config["updata"] = False
+            Fishsys.缓存(1, config)
 
-    help_mod = logs.输入(f"这是Fishconsole的开发文档，如果想查看，请按任意字符开始")
+    logs.输入(f"这是Fishconsole的开发文档，如果想查看，请按任意字符开始")
     if True:
         res = window.列表选择对话框(
             "我如何重新进入？\n"
@@ -129,7 +117,7 @@ def 帮助():
             f"Fishconsole {fcv.version()} 帮助文档",
             ["Matplotlib中文辅助模块", "easygui中文辅助模块", "logs控制台输出辅助模块", "Fishsys模块"])
         logs.系统日志(f"用户请求启动{res}")
-        if res == None:
+        if res is None:
             logs.安全退出("用户取消了操作")
         if res is not None:
             for a in res:
@@ -385,8 +373,9 @@ def 帮助():
                         "官网存活性检测",
                     ])
                     logs.系统日志(f"用户请求启动{res}")
-                    if res == None:
+                    if res is None:
                         logs.安全退出("用户取消了操作")
+                    # noinspection PyAssignmentToLoopOrWithParameter
                     for a in res:
                         if a == "官网存活性检测":
                             window.弹窗(
@@ -467,4 +456,3 @@ def 帮助():
                                 "如果传入的变量类型符合预期的变量类型，就返回Ture，否则返回False。\n\n"
                                 "其实也就那样了\n"
                                 , "强制类型检测", "ok")
-
