@@ -11,6 +11,9 @@
 
 """
 
+import datetime
+模块开始 = datetime.datetime.now()
+
 import matplotlib.pyplot as plt
 from Fishconsole import Fishsys
 from Fishconsole import logs
@@ -23,12 +26,14 @@ def 单线折线图(x轴范围, x轴数据源: list, y轴范围, y轴数据源:
     a=Fishsys.强制类型检测(x轴数据源,"list")
     b=Fishsys.强制类型检测(y轴数据源,"list")
     if a:
-        1+1;
+        # noinspection PyStatementEffect
+        1+1
     else:
         logs.安全退出("huitu》强制类型检测》单线折现图》请对x轴数据源使用list类型的数据")
 
     if b:
-        1+1;
+        # noinspection PyStatementEffect
+        1+1
     else:
         logs.安全退出("huitu》强制类型检测》单线折现图》请对y轴数据源使用list类型的数据")
     # 修复可能出现的负数
@@ -64,18 +69,22 @@ def 双线折线图(x轴范围, x轴数据源: list, y轴范围, y轴数据源:
     c=Fishsys.强制类型检测(xa轴数据源, "list")
     d=Fishsys.强制类型检测(ya轴数据源, "list")
     if a:
+        # noinspection PyStatementEffect
         1+1
     else:
         logs.安全退出("huitu》强制类型检测》双线折现图》请对x轴数据源使用list类型的数据")
     if b:
+        # noinspection PyStatementEffect
         1+1
     else:
         logs.安全退出("huitu》强制类型检测》双线折现图》请对y轴数据源使用list类型的数据")
     if c:
+        # noinspection PyStatementEffect
         1+1
     else:
         logs.安全退出("huitu》强制类型检测》双线折现图》请对xa轴数据源使用list类型的数据")
     if d:
+        # noinspection PyStatementEffect
         1+1
     else:
         logs.安全退出("huitu》强制类型检测》双线折现图》请对ya轴数据源使用list类型的数据")
@@ -133,34 +142,42 @@ def 子图(模式, 总标题=None, 子图a标题=None, 子图b标题=None, 子
     g=Fishsys.强制类型检测(xc轴数据源, "list")
     h=Fishsys.强制类型检测(xc轴数据源, "list")
     if a:
+        # noinspection PyStatementEffect
         1+1
     else:
         logs.安全退出("huitu》强制类型检测》子图》请对x轴数据源使用list类型的数据")
     if b:
+        # noinspection PyStatementEffect
         1+1
     else:
         logs.安全退出("huitu》强制类型检测》子图》请对y轴数据源使用list类型的数据")
     if c:
+        # noinspection PyStatementEffect
         1+1
     else:
         logs.安全退出("huitu》强制类型检测》子图》请对xa轴数据源使用list类型的数据")
     if d:
+        # noinspection PyStatementEffect
         1+1
     else:
         logs.安全退出("huitu》强制类型检测》子图》请对ya轴数据源使用list类型的数据")
     if e:
+        # noinspection PyStatementEffect
         1+1
     else:
         logs.安全退出("huitu》强制类型检测》子图》请对xb轴数据源使用list类型的数据")
     if f:
+        # noinspection PyStatementEffect
         1+1
     else:
         logs.安全退出("huitu》强制类型检测》子图》请对yc轴数据源使用list类型的数据")
     if g:
+        # noinspection PyStatementEffect
         1+1
     else:
         logs.安全退出("huitu》强制类型检测》子图》请对xc轴数据源使用list类型的数据")
     if h:
+        # noinspection PyStatementEffect
         1+1
     else:
         logs.安全退出("huitu》强制类型检测》子图》请对yc轴数据源使用list类型的数据")
@@ -335,14 +352,17 @@ def 柱形图(x轴名: list, y轴数据: list, 背景: list = None, 模式="竖"
     b=Fishsys.强制类型检测(y轴数据, "list")
     c=Fishsys.强制类型检测(背景, "list")
     if a:
+        # noinspection PyStatementEffect
         1+1
     else:
         logs.安全退出("huitu》强制类型检测》柱形图》请对x轴名使用list类型的数据")
     if b:
+        # noinspection PyStatementEffect
         1+1
     else:
         logs.安全退出("huitu》强制类型检测》柱形图》请对y轴数据使用list类型的数据")
     if c:
+        # noinspection PyStatementEffect
         1+1
     else:
         logs.安全退出("huitu》强制类型检测》柱形图》请对背景使用list类型的数据")
@@ -365,19 +385,17 @@ def 饼图(数据: list, 数据标签: list = None, 数据颜色: list = None, 
     plt.title(总标题)  # 设置标题
     a=Fishsys.强制类型检测(数据, "list")
     b=Fishsys.强制类型检测(数据标签, "list")
-    c=Fishsys.强制类型检测(数据颜色, "list")
     if a:
+        # noinspection PyStatementEffect
         1+1
     else:
         logs.安全退出("huitu》强制类型检测》饼图》请对数据使用list类型的数据")
     if b:
+        # noinspection PyStatementEffect
         1+1
     else:
         logs.安全退出("huitu》强制类型检测》饼图》请对数据标签使用list类型的数据")
-    if c:
-        1+1
-    else:
-        logs.安全退出("huitu》强制类型检测》饼图》请对数据颜色使用list类型的数据")
+
     if 百分比:
         plt.pie(数据, labels=数据标签, colors=数据颜色, autopct='%.2f%%')
     # 修复可能出现的负数
@@ -385,3 +403,6 @@ def 饼图(数据: list, 数据标签: list = None, 数据颜色: list = None, 
     # 配置字体
     plt.rcParams['font.sans-serif'] = ['SimHei']
     plt.show()
+
+模块结束 = datetime.datetime.now()
+logs.系统日志(f'Fishsys运行时间为：{模块结束-模块开始}')
\ No newline at end of file
