@@ -7,9 +7,13 @@
 
 """
 
-from Fishconsole import fcv
+import datetime
 import sys
-import  os
+
+from Fishconsole import fcv
+
+模块开始 = datetime.datetime.now()
+
 
 def 颜色(text, 色选="None"):
     """
@@ -152,9 +156,6 @@ def 分割线(标题, text, 色选="Nona"):
         return f"\n\n\n\n\n\n- {标题} -  {text}:\n--------------------------\n"
 
 
-
-
-
 def 变量查看(变量名: str, 变量, 色选: str = "红色"):
     """
     FishCosnole LOGS 变量查看模块
@@ -172,28 +173,37 @@ def 变量查看(变量名: str, 变量, 色选: str = "红色"):
     :return: 经过某种方法格式化后的文字
     """
     行位置 = sys._getframe(1).f_lineno
-    type值=str(type(变量))
-    变量类型=type值.split("'")[1]
+    type值 = str(type(变量))
+    变量类型 = type值.split("'")[1]
 
-    计数器=0
-    temp=str(变量)
-    for a in temp:
-        计数器=计数器+1
-        print(计数器)
-    计数器=计数器*1.4
-    计数器=str(计数器)
-    计数器=计数器.split(".")[0]
-    计数器=int(计数器)
-    计数器=计数器+32
-    print(计数器)
-    print("="*计数器)
-    print(日志(f"  ||（{颜色('变量名', 色选)}：{变量名}）（{颜色('数据', 色选)}：{变量}）（{颜色('类型', 色选)}: {变量类型}）（{颜色('位置', 色选)}:{行位置}）||"))
-    print("="*计数器+"\n\n")
+    计数器a = 0
+    for _ in 变量类型:
+        计数器a = 计数器a + 1
+    计数器a = 计数器a * 1.4
+    计数器a = str(计数器a)
+    计数器a = 计数器a.split(".")[0]
+    计数器a = int(计数器a)
+
+    计数器 = 0
+    temp = str(变量)
+    for _ in temp:
+        计数器 = 计数器 + 1
+    计数器 = 计数器 * 1.2
+    计数器 = str(计数器)
+    计数器 = 计数器.split(".")[0]
+    计数器 = int(计数器)
+    计数器 = 计数器 + 22 + 计数器a
+    print("=" * 计数器)
+    print(日志(f"  ||（{颜色('变量名', 色选)}：{变量名}）"))
+    print(日志(f"  ||（{颜色('数据', 色选)}：{变量}）"))
+    print(日志(f"  ||（{颜色('类型', 色选)}: {变量类型}）"))
+    print(日志(f"  ||（{颜色('位置', 色选)}:{行位置}）"))
+
+    print("=" * 计数器 + "\n\n")
 
 
-
-def 安全退出(内容,变量=None):
-        """
+def 安全退出(内容, 变量=None):
+    """
         FishConsole LOGS安全退出
 
         ----
@@ -204,16 +214,12 @@ def 安全退出(内容,变量=None):
         :param 变量: 传入的变量（默认没有）
         :return: 显示你输入的文字并结束程序
         """
-        a = sys._getframe(1).f_lineno
-        if 变量 is None:
-            sys.exit(日志(f"》Fishconsole {fcv.version()}安全退出》{内容} || line[{a}] ","红色"))
-        else:
-            变量查看("temp",变量)
-            sys.exit(日志(f"》Fishconsole {fcv.version()}安全退出》{内容} || line[{a}] ","红色"))
-
-
-
-
+    a = sys._getframe(1).f_lineno
+    if 变量 is None:
+        sys.exit(日志(f"》Fishconsole {fcv.version()}安全退出》{内容} || line[{a}] ", "红色"))
+    else:
+        变量查看("temp", 变量)
+        sys.exit(日志(f"》Fishconsole {fcv.version()}安全退出》{内容} || line[{a}] ", "红色"))
 
 
 # print(日志(123, 色选="红色"))
@@ -222,3 +228,5 @@ def 安全退出(内容,变量=None):
 # a = finput("你你你你你你像个傻逼一样", 全局参数)
 # 错误跟踪(["Fishconsole", "logs", "错误跟踪"], "笑死了","哈哈哈")
 系统日志("用户调用了logs模块")
+模块结束 = datetime.datetime.now()
+系统日志(f'logs运行时间为：{模块结束 - 模块开始}')
