@@ -6,14 +6,17 @@
 ----
 
 """
+import datetime
+
+模块开始 = datetime.datetime.now()
 
 import easygui
 # 虽然没什么用，但是里面的强制更新系统可以很好的牵制调用
 from Fishconsole import Fishsys
 from Fishconsole import logs
-from  Fishconsole  import fcv
-logs.系统日志("用户调用了window模块")
+from Fishconsole import fcv
 
+logs.系统日志("用户调用了window模块")
 
 
 def 弹窗(显示文字, 标题, 确认显示文字):
@@ -23,24 +26,26 @@ def 弹窗(显示文字, 标题, 确认显示文字):
     easygui.msgbox(显示文字, 标题, 确认显示文字)
 
 
+# noinspection PyStatementEffect
 def 选择对话框(显示文字, 标题, 选项: list, 图片地址: str = None):
-    a=Fishsys.强制类型检测(选项,"list")
+    a = Fishsys.强制类型检测(选项, "list")
     if a:
-        1+1
+        1 + 1
     else:
-        print(logs.日志(f"Fishconsole{fcv.version()}》window》选择对话框》强制类型检测》请指定list类型的数据源","红色"))
+        print(logs.日志(f"Fishconsole{fcv.version()}》window》选择对话框》强制类型检测》请指定list类型的数据源", "红色"))
     显示文字 = str(显示文字)
     标题 = str(标题)
     返回 = easygui.buttonbox(image=图片地址, msg=显示文字, title=标题, choices=选项)
     return 返回
 
 
+# noinspection PyStatementEffect
 def 列表选择对话框(显示文字, 标题, 选项: list):
-    a=Fishsys.强制类型检测(选项,"list")
+    a = Fishsys.强制类型检测(选项, "list")
     if a:
-        1+1
+        1 + 1
     else:
-        print(logs.日志(f"Fishconsole{fcv.version()}》window》列表选择对话框》强制类型检测》请指定list类型的数据源","红色"))
+        print(logs.日志(f"Fishconsole{fcv.version()}》window》列表选择对话框》强制类型检测》请指定list类型的数据源", "红色"))
     标题 = str(标题)
     返回 = easygui.multchoicebox(msg=显示文字, title=标题, choices=选项)
     return 返回
@@ -76,6 +81,8 @@ def 文件选择():
 def 文件保存():
     返回 = easygui.filesavebox()
     return 返回
+
+
 # 弹窗(1,2,3)
 # print(选择对话框(1,2,选项=["ab","cd","ef"],图片地址="h.PNG"))
 # print(列表选择对话框(1,2,选项=["ab","cd"]))
@@ -84,3 +91,5 @@ def 文件保存():
 # print(文件选择())
 # print(文件保存())
 
+模块结束 = datetime.datetime.now()
+logs.系统日志(f'Fishsys运行时间为：{模块结束 - 模块开始}')
